@@ -37,9 +37,12 @@ import requests
 class DataProcessingAndMessaging:
     def __init__(self):
         # -------------------------- 1. 主类日志初始化 --------------------------
+                # -------------------------- 1. 主类日志初始化 --------------------------
         # 获取调用者的堆栈信息（主类日志关联调用脚本）
         caller_frame = inspect.stack()[1]
         caller_filename = caller_frame.filename
+        # 修复：处理中文文件名/路径的编码问题（确保日志文件名正确）
+        caller_filename = os.path.abspath(caller_filename)
         log_file = os.path.splitext(os.path.basename(caller_filename))[0] + ".log"
 
         # 初始化主类日志记录器
@@ -47,10 +50,10 @@ class DataProcessingAndMessaging:
         self.logger.setLevel(logging.INFO)
         # 避免重复添加处理器
         if not self.logger.handlers:
-            # 文件处理器（保存到日志文件）
+            # 文件处理器（保存到日志文件）- 修复：显式指定UTF-8编码
             file_handler = logging.FileHandler(log_file, encoding='utf-8')
             file_handler.setFormatter(logging.Formatter('%(asctime)s - %(levelname)s - %(message)s'))
-            # 控制台处理器（方便开发调试）
+            # 控制台处理器（方便开发调试）- 修复：显式指定UTF-8编码（部分终端需配置）
             console_handler = logging.StreamHandler()
             console_handler.setFormatter(logging.Formatter('%(asctime)s - %(levelname)s - %(message)s'))
             # 添加处理器
